@@ -1,14 +1,16 @@
+## no critic: TestingAndDebugging::RequireUseStrict
 package Getopt::Long::Less;
 
-our $DATE = '2019-02-02'; # DATE
-our $VERSION = '0.090'; # VERSION
-
-use 5.010001;
-use strict 'subs', 'vars';
 # IFUNBUILT
+# use strict 'subs', 'vars';
 # use warnings;
 # END IFUNBUILT
 
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2023-05-04'; # DATE
+our $DIST = 'Getopt-Long-Less'; # DIST
+our $VERSION = '0.091'; # VERSION
+
 our @EXPORT   = qw(GetOptions);
 our @EXPORT_OK = qw(Configure GetOptionsFromArray);
 
@@ -128,9 +130,9 @@ sub GetOptionsFromArray {
             $val = shift;
         } else {
             if ($parsed->{is_inc} && $ref eq 'SCALAR') {
-                $val = ($$destination // 0) + 1;
+                $val = (defined($$destination) ? $$destination : 0) + 1;
             } elsif ($parsed->{is_inc} && $vals) {
-                $val = ($vals->{$name} // 0) + 1;
+                $val = (defined $vals->{$name} ? $vals->{$name} : 0) + 1;
             } elsif ($parsed->{type} && $parsed->{type} eq 'i' ||
                          $parsed->{opttype} && $parsed->{opttype} eq 'i') {
                 $val = 0;
@@ -314,23 +316,27 @@ sub parse_getopt_long_opt_spec {
                    (?:
                        :
                        (?P<opttype>[siof])
-                       (?P<desttype>|[%@])
+                       (?P<desttype>|[%@])?
                    ) |
                    (?:
                        :
-                       (?P<optnum>\d+)
-                       (?P<desttype>|[%@])
-                   )
+                       (?P<optnum>-?\d+)
+                       (?P<desttype>|[%@])?
+                   ) |
                    (?:
                        :
                        (?P<optplus>\+)
-                       (?P<desttype>|[%@])
+                       (?P<desttype>|[%@])?
                    )
                )?
                \z/x
-                   or return undef;
+                   or return;
     my %res = %+;
 
+    if (defined $res{optnum}) {
+        $res{type} = 'i';
+    }
+
     if ($res{aliases}) {
         my @als;
         for my $al (split /\|/, $res{aliases}) {
@@ -383,7 +389,7 @@ Getopt::Long::Less - Like Getopt::Long, but with less features
 
 =head1 VERSION
 
-This document describes version 0.090 of Getopt::Long::Less (from Perl distribution Getopt-Long-Less), released on 2019-02-02.
+This document describes version 0.091 of Getopt::Long::Less (from Perl distribution Getopt-Long-Less), released on 2023-05-04.
 
 =head1 DESCRIPTION
 
@@ -431,14 +437,6 @@ Please visit the project's homepage at L<https://metacpan.org/release/Getopt-Lon
 
 Source repository is at L<https://github.com/perlancar/perl-Getopt-Long-Less>.
 
-=head1 BUGS
-
-Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Getopt-Long-Less>
-
-When submitting a bug or request, please include a test-file or a
-patch to an existing test-file that illustrates the bug or desired
-feature.
-
 =head1 SEE ALSO
 
 L<Getopt::Long>
@@ -451,11 +449,37 @@ Benchmarks in L<Bencher::Scenario::GetoptModules>
 
 perlancar <perlancar@cpan.org>
 
+=head1 CONTRIBUTING
+
+
+To contribute, you can send patches by email/via RT, or send pull requests on
+GitHub.
+
+Most of the time, you don't need to build the distribution yourself. You can
+simply modify the code, then test via:
+
+ % prove -l
+
+If you want to build the distribution (e.g. to try to install it locally on your
+system), you can install L<Dist::Zilla>,
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>,
+L<Pod::Weaver::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla- and/or Pod::Weaver plugins. Any additional steps required beyond
+that are considered a bug and can be reported to me.
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2019, 2016, 2015 by perlancar@cpan.org.
+This software is copyright (c) 2023, 2019, 2016, 2015 by perlancar <perlancar@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Getopt-Long-Less>
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
 =cut
